@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.1.0';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.1.1';
 #pod =encoding UTF-8
 #pod
 #pod =head1 SYNOPSIS
@@ -125,8 +125,8 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.1.0';
 #pod     #
 #pod     # Copy files back into project dir
 #pod     #
-#pod     [CopyFilesFromRelease]
-#pod     filename = cpanfile
+#pod     [CopyFilesFromBuild]
+#pod     copy = cpanfile
 #pod
 #pod     #
 #pod     # Release
@@ -331,8 +331,8 @@ sub configure {
         #
         # Replacement of files in project dir
         #
-        [ 'CopyFilesFromRelease' => {     # copy cpanfile back into project dir
-            'filename' => 'cpanfile',
+        [ 'CopyFilesFromBuild' => {     # copy cpanfile back into project dir
+            'copy' => 'cpanfile',
         }],
 
         #
@@ -364,7 +364,7 @@ __PACKAGE__->meta->make_immutable;
 {
     package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
     # ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.1.0';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.1.1';
 use Moose;
     use namespace::autoclean;
 
@@ -412,7 +412,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 3.1.0
+version 3.1.1
 
 =head1 SYNOPSIS
 
@@ -541,8 +541,8 @@ Currently this plugin bundle is equivalent to:
     #
     # Copy files back into project dir
     #
-    [CopyFilesFromRelease]
-    filename = cpanfile
+    [CopyFilesFromBuild]
+    copy = cpanfile
 
     #
     # Release
